Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2942)

Unified Diff: ios/chrome/browser/ui/content_suggestions/content_suggestions_expandable_item.h

Issue 2644123003: Move ios/ui/suggestions to ios/ui/content_suggestions (Closed)
Patch Set: Rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/ui/content_suggestions/content_suggestions_expandable_item.h
diff --git a/ios/chrome/browser/ui/suggestions/suggestions_expandable_item.h b/ios/chrome/browser/ui/content_suggestions/content_suggestions_expandable_item.h
similarity index 62%
rename from ios/chrome/browser/ui/suggestions/suggestions_expandable_item.h
rename to ios/chrome/browser/ui/content_suggestions/content_suggestions_expandable_item.h
index 174ab5c8f2c095ce3297d8b72c40d19949bc6e54..4e505282f3db18a3f7c0871412214bbd34a4034c 100644
--- a/ios/chrome/browser/ui/suggestions/suggestions_expandable_item.h
+++ b/ios/chrome/browser/ui/content_suggestions/content_suggestions_expandable_item.h
@@ -2,18 +2,18 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IOS_CHROME_BROWSER_UI_SUGGESTIONS_SUGGESTIONS_EXPANDABLE_ITEM_H_
-#define IOS_CHROME_BROWSER_UI_SUGGESTIONS_SUGGESTIONS_EXPANDABLE_ITEM_H_
+#ifndef IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_EXPANDABLE_ITEM_H_
+#define IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_EXPANDABLE_ITEM_H_
#import "ios/chrome/browser/ui/collection_view/cells/collection_view_item.h"
-#import "ios/chrome/browser/ui/suggestions/expandable_item.h"
+#import "ios/chrome/browser/ui/content_suggestions/expandable_item.h"
#import "ios/third_party/material_components_ios/src/components/CollectionCells/src/MaterialCollectionCells.h"
-@class SuggestionsExpandableCell;
+@class ContentSuggestionsExpandableCell;
-// Delegate for the SuggestionsExpandableCell. The delegate will take care of
-// the expansion/collapsing of the cell.
-@protocol SuggestionsExpandableCellDelegate
+// Delegate for the ContentSuggestionsExpandableCell. The delegate will take
+// care of the expansion/collapsing of the cell.
+@protocol ContentSuggestionsExpandableCellDelegate
- (void)expandCell:(UICollectionViewCell*)cell;
- (void)collapseCell:(UICollectionViewCell*)cell;
@@ -22,8 +22,7 @@
// Item for an expandable article in the suggestions. An expandable article can
// be expanded, displaying more informations/interactions.
-@interface SuggestionsExpandableItem
- : CollectionViewItem<SuggestionsExpandableArticle>
+@interface SuggestionsExpandableItem : CollectionViewItem<ExpandableItem>
// Init the article with a |title|, a |subtitle| an |image| and some |detail|
// displayed only when the article is expanded. |type| is the type of the item.
@@ -36,14 +35,16 @@
- (instancetype)initWithType:(NSInteger)type NS_UNAVAILABLE;
// Delegate for the configured cells.
-@property(nonatomic, weak) id<SuggestionsExpandableCellDelegate> delegate;
+@property(nonatomic, weak) id<ContentSuggestionsExpandableCellDelegate>
+ delegate;
@end
// Corresponding cell of an expandable article.
-@interface SuggestionsExpandableCell : MDCCollectionViewCell
+@interface ContentSuggestionsExpandableCell : MDCCollectionViewCell
-@property(nonatomic, weak) id<SuggestionsExpandableCellDelegate> delegate;
+@property(nonatomic, weak) id<ContentSuggestionsExpandableCellDelegate>
+ delegate;
@property(nonatomic, readonly, strong) UILabel* titleLabel;
@property(nonatomic, readonly, strong) UILabel* subtitleLabel;
@property(nonatomic, readonly, strong) UILabel* detailLabel;
@@ -54,4 +55,4 @@
@end
-#endif // IOS_CHROME_BROWSER_UI_SUGGESTIONS_SUGGESTIONS_EXPANDABLE_ITEM_H_
+#endif // IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_EXPANDABLE_ITEM_H_

Powered by Google App Engine
This is Rietveld 408576698